=========
Changelog
=========

Version 0.X (unreleased)
========================
-

Version 0.1
========================

- Add smecv grid support
- Add reader from images and image stacks
- Add reshuffle module
- Add first version of metadata module
- Add basic documentation
- Add unit tests for all modules
